@@ -1,4 +1,5 @@
 #include <Rinternals.h>
+#include <R_ext/Rdynload.h>
 void do_gemm(const double *x, int nrx, int ncx,
              const double *y, int nry, int ncy,
              double *z);
@@ -11,6 +12,8 @@ void do_gemm3(double *x, int nrx, int ncx,
 SEXP getListElement(SEXP list, const char *str);
 SEXP getListElementIfThere(SEXP list, const char *str);
 
+DL_FUNC get_func_from_ptr(SEXP extPtr);
+
 #ifdef __cplusplus
 extern "C" {
 #endif
